summaryrefslogtreecommitdiffstats
path: root/kioslaves/mbox/mboxfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'kioslaves/mbox/mboxfile.h')
-rw-r--r--kioslaves/mbox/mboxfile.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kioslaves/mbox/mboxfile.h b/kioslaves/mbox/mboxfile.h
index a628e381..b8a98973 100644
--- a/kioslaves/mbox/mboxfile.h
+++ b/kioslaves/mbox/mboxfile.h
@@ -32,9 +32,9 @@ public:
/**
* Constructor
* @param info The urlinfo which must be used
* @param tqparent The MBoxProtocol tqparent instance, used to throw errors.
*/
- MBoxFile( const UrlInfo* info, MBoxProtocol* tqparent );
+ MBoxFile( const UrlInfo* info, MBoxProtocol* parent );
/**
* Empty destructor
@@ -61,7 +61,7 @@ protected:
const UrlInfo* const m_info;
/**
* A instance of the tqparent protocol, meant to throw errors if neccesairy.
*/
MBoxProtocol* const m_mbox;
};
@@ -32,9 +32,9 @@ public:
* Constructor
* @param info The urlinfo which must be used
- * @param tqparent The MBoxProtocol tqparent instance, used to throw errors.
+ * @param parent The MBoxProtocol parent instance, used to throw errors.
*/
@@ -61,7 +61,7 @@ protected:
const UrlInfo* const m_info;
/**
- * A instance of the tqparent protocol, meant to throw errors if neccesairy.
+ * A instance of the parent protocol, meant to throw errors if neccesairy.
*/
MBoxProtocol* const m_mbox;